/* Configuration for diskflags generated by Alire */
#ifndef DISKFLAGS_CONFIG_H
#define DISKFLAGS_CONFIG_H

#define CRATE_VERSION "0.1.0-dev"
#define CRATE_NAME "diskflags"

#define ALIRE_HOST_OS "linux"

#define ALIRE_HOST_ARCH "x86_64"

#define ALIRE_HOST_DISTRO "ubuntu"

#define BUILD_PROFILE_RELEASE 1
#define BUILD_PROFILE_VALIDATION 2
#define BUILD_PROFILE_DEVELOPMENT 3

#define BUILD_PROFILE  1

#endif
